﻿import { Component, OnInit } from '@angular/core';
import { Router } from '@angular/router';

import { environment } from '../../../environments/environment';
import { AuthenticationService } from '../../services/authentication.service';
import { AuthenticationHolderService } from '../../services/authentication-holder.service';
import { UiUtilsService } from '../../services/ui-utils.service';

@Component({
	selector: 'app-sign-in',
	templateUrl: './sign-in.component.html',
	styleUrls: ['./sign-in.component.css']
})
export class SignInComponent implements OnInit {

	//Bindables
	public userName: string = null;
	public password: string = null;
	public isBusy: boolean = false;

	/**
	   * Constructor
	   */
	constructor(
		private authenticationService: AuthenticationService,
		private authenticationHolderService: AuthenticationHolderService,
		private router: Router,
		private uiUtilsService: UiUtilsService) {
	}

    /**
     * Raise on init of component 
     */
	ngOnInit() {

		//Set username for DEBUG (only "dev" enviroment)
		if (!environment.production) {
			this.userName = "maurob";
		}		  
	}

	/**
	 * Signin on remote server
	 */
	public signIn() {

		//Prevent submission on missing data
		if (!this.userName || !this.password) {
			this.uiUtilsService.warning("Missing required data");
			return;
		}

		//Invoke remote server
		this.isBusy = true;
		this.authenticationService.signIn(this.userName, this.password).subscribe(

			//Success
			(response) => {
				this.isBusy = false;
				this.uiUtilsService.success("Authentication completed");
				this.router.navigate([""]);
			},

			//Error
			(error) => {
				this.isBusy = false;
				this.uiUtilsService.warning("Provided credentials are invalid");
				console.error(error);
			}
		);
	}
}