﻿import { BrowserModule } from '@angular/platform-browser';
import { NgModule } from '@angular/core';
import { FormsModule } from '@angular/forms';
import { HttpModule } from '@angular/http';

import { AppRouting } from './app.routing';
import { AppComponent } from './app.component';
import { SignInComponent } from './account/sign-in/sign-in.component';
import { HeaderComponent } from './structure/header/header.component';
import { FooterComponent } from './structure/footer/footer.component';
import { HomeComponent } from './home/home/home.component';
import { CategoriesComponent } from './categories/categories/categories.component';

import { AuthenticationHolderService } from './services/authentication-holder.service';
import { AuthenticationService } from './services/authentication.service';
import { DatabankService } from './services/databank.service';
import { UiUtilsService } from './services/ui-utils.service';
import { MomentDatePipe } from './pipes/moment-date.pipe';

import { IsAuthenticatedGuard } from './guards/is-authenticated.guard';
import { IsAnonymousGuard } from './guards/is-anonymous.guard';

@NgModule({
  declarations: [
    AppComponent,
	  SignInComponent,
	  HeaderComponent,
	  FooterComponent,
	  HomeComponent,
	  MomentDatePipe,
	  CategoriesComponent,
  ],
  imports: [
    BrowserModule,
    FormsModule,
	  HttpModule, 
	  AppRouting, 
  ],
  providers: [
	  AuthenticationHolderService,
	  AuthenticationService,
	  UiUtilsService,
	  DatabankService,
	  IsAuthenticatedGuard,
	  IsAnonymousGuard
  ],
  bootstrap: [AppComponent]
})
export class AppModule { }
