﻿import { Component, OnInit, ViewChild } from '@angular/core';

import { CategoryContract } from '../../models/category-contract';
import { AuthenticationHolderService } from '../../services/authentication-holder.service';
import { DatabankService } from '../../services/databank.service';
import { UiUtilsService } from '../../services/ui-utils.service';

@Component({
	selector: 'app-categories',
	templateUrl: './categories.component.html',
	styleUrls: ['./categories.component.css']
})
export class CategoriesComponent implements OnInit {

	//Bindables
	public isBusy: boolean = false;
	public categories: CategoryContract[] = [];
    
    /**
     * Constructor
     * @param authenticationHolderService Authentication holder
     * @param DatabankService Databank service
     */
	constructor(
		private authenticationHolderService: AuthenticationHolderService,
		private databankService: DatabankService,
		private uiUtilsService: UiUtilsService) {
	}

    /**
     * Raised after component init
     */
	public ngOnInit(): void {

        //Fetch list of data from server
		this.fetchAllCategories();
	}

    /**
     * Fetch list of all categories
     */
	public fetchAllCategories(): void {

        //Invoke server
		this.isBusy = true;
		this.databankService.fetchAllCategories().subscribe(

            //Success
			(response) => {

				//Set categories on property
				this.isBusy = false;
				this.categories = response;
			}, 

            //Error
			(error) => {

				//Show error message
				this.isBusy = false;
				this.uiUtilsService.auto(error);
			}
		);
	}    
}

