﻿import { Injectable } from '@angular/core';
import { Router } from '@angular/router';
import { CanActivate, ActivatedRouteSnapshot, RouterStateSnapshot } from '@angular/router';
import { Observable } from 'rxjs/Observable';

import { AuthenticationHolderService } from '../services/authentication-holder.service';

@Injectable()
export class IsAuthenticatedGuard implements CanActivate {

	constructor(
		private authenticationHolderService: AuthenticationHolderService,
		private router: Router) {
	}

    /**
     * Can activate component
     * @param next Next route
     * @param state Current state
     */
	public canActivate(
		next: ActivatedRouteSnapshot,
		state: RouterStateSnapshot): Observable<boolean> | Promise<boolean> | boolean {

		//If user is authenticated
		if (this.authenticationHolderService.isAuthenticated) {

			//Confirm
			return true;
		}

		//Otherwise, is NOT authenticated, redirect to sign-in
		this.router.navigate(['sign-in']);
		return false;
	}
}
