﻿import { Component, OnInit } from '@angular/core';
import { Router } from '@angular/router';

import { environment } from '../../../environments/environment';
import { AuthenticationService } from '../../services/authentication.service';
import { AuthenticationHolderService } from '../../services/authentication-holder.service';
import { UiUtilsService } from '../../services/ui-utils.service';
import { DatabankService } from '../../services/databank.service';

@Component({
  selector: 'app-home',
  templateUrl: './home.component.html',
  styleUrls: ['./home.component.css']
})
export class HomeComponent implements OnInit {

	//Bindables     
	public isBusy: boolean = false;
	public userId: string = null;
	public userName: string = null;
	public personName: string = null;
	public personSurname: string = null;
	public email: string = null;
	public lastAccessDate: string = null;
	public totalCategories: number = 0;
	public totalUsers: number = 0;

    /**
     * Constructor
     */
	constructor(
		private authenticationHolderService: AuthenticationHolderService,
		private databankService: DatabankService,
		private router: Router,
		private uiUtilsService: UiUtilsService) {
	}

    /**
     * Raise on init of component 
     */
	ngOnInit() {		

		//Set authentication data on component
		this.userId = this.authenticationHolderService.userId;
		this.email = this.authenticationHolderService.email;
		this.userName = this.authenticationHolderService.userName;
		this.personName = this.authenticationHolderService.personName;
		this.personSurname = this.authenticationHolderService.personSurname;
		this.lastAccessDate = this.authenticationHolderService.lastAccessDate;

		//Count all indicators
		this.countAllIndicators();
	}

    /**
     * Shows message to user
     */
	public showNotImplementedMessage() {

        //Show message using service
		this.uiUtilsService.info("Feature is not implemented!");
	}

    /**
     * Count all indicators
     */
	private countAllIndicators(): void {


        //Start count methods
		this.countAllCategories();
	}

    /**
     * Retrieve count of all categories
     */
	private countAllCategories(): void {

		//Set indicator and invoke service
		this.isBusy = true;
		this.databankService.countAllCategories().subscribe(
			(response) => {
				this.isBusy = false;
				this.totalCategories = response.value;

				//Invoke "count users""
				this.countAllUsers();
			},
			(error) => {
				this.isBusy = false;
				this.uiUtilsService.error("Server raised an error");
			},
		);
	}

    /**
     * Retrieve count of all users
     */
	private countAllUsers(): void {

		//Set indicator and invoke service
		this.isBusy = true;
		this.databankService.countAllUsers().subscribe(
			(response) => {
				this.isBusy = false;
				this.totalUsers = response.value;
			},
			(error) => {
				this.isBusy = false;
				this.uiUtilsService.error("Server raised an error");
			},
		);
	}

    //**************************************************
    //*** ASYNC/AWAIT version
    //**************************************************

 //   /**
 //    * Count all indicators
 //    */
	//private async countAllIndicators() {

 //       //Count all categories
	//	await this.countCategories();

	//	//Count all users
	//	await this.countCategories();		
	//} 

 //   /**
 //    * Retrieve count of categories
 //    */
	//private countCategories() {

 //       //Wrap everything in a promise
	//	return new Promise<void>((resolve, reject) => {

 //           //Set indicator and invoke service
	//		this.isBusy = true;
	//		this.databankService.countAllCategories().subscribe(
	//			(response) => {
	//				this.isBusy = false;
	//				this.totalCategories = response.value;
	//				resolve();
	//			}, 
	//			(error) => {
	//				this.isBusy = false;
	//				this.uiUtilsService.error("Server raised an error");
	//				reject();
	//			}, 
	//		);
	//	});
	//}

 //   /**
 //    * Retrieve count of users
 //    */
	//private countUsers() {

	//	//Wrap everything in a promise
	//	return new Promise<void>((resolve, reject) => {

	//		//Set indicator and invoke service
	//		this.isBusy = true;
	//		this.databankService.countAllUsers().subscribe(
	//			(response) => {
	//				this.isBusy = false;
	//				this.totalUsers = response.value;
	//				resolve();
	//			},
	//			(error) => {
	//				this.isBusy = false;
	//				this.uiUtilsService.error("Server raised an error");
	//				reject();
	//			},
	//		);
	//	});
	//}
}
