﻿import { Injectable } from '@angular/core';

@Injectable()
export class AuthenticationHolderService {

	//Bindables
	public isAuthenticated: boolean = false;
	public lang: string = "it";
	public userId: string = null;
	public userName: string = null;
	public email: string = null;
	public password: string = null;
	public lastAccessDate: string = null;
	public personName: string = null;
	public personSurname: string = null;

	private AUTH_STORAGE: string = "AUTH_STORAGE";

    /**
     * Set authentication over
     * @param authenticationData Authentication data
     */
	public setAuthentication(authenticationData: any) {

		//Clear authentication
		this.clearAuthentication();

		//If data is invalid, exit
		if (!authenticationData)
			return;

		//Set authentication
		this.isAuthenticated = authenticationData != null;

		//Set data
		this.userId = authenticationData.userId;
		this.userName = authenticationData.userName;
		this.email = authenticationData.email;
		this.password = authenticationData.password;
		this.lastAccessDate = authenticationData.lastAccessDate;
		this.personName = authenticationData.personName;
		this.personSurname = authenticationData.personSurname;

		//Create object for local storage
		var structureForLocalstorage = {
			isAuthenticated: this.isAuthenticated,
			userId: this.userId,
			userName: this.userName,
			email: this.email,
			password: this.password,
			lastAccessDate: this.lastAccessDate,
			personName: this.personName,
			personSurname: this.personSurname
		};

		//Serialize as string 
		let json = JSON.stringify(structureForLocalstorage);

		//Set on local storage
		localStorage.setItem(this.AUTH_STORAGE, json);
	}

    /**
     * Clears current autentication
     */
	public clearAuthentication() {

		//Remove data 
		this.isAuthenticated = false
		this.userId = null;
		this.userName = null;
		this.email = null;
		this.password = null;
		this.lastAccessDate = null;
		this.personName = null;
		this.personSurname = null;

		//Remove from local storage
		localStorage.removeItem(this.AUTH_STORAGE);
	}

    /**
     * Try to restore data from local storage
     */
	public tryRestore() {

		//Try to get element from localstorage
		var jsonData = localStorage.getItem(this.AUTH_STORAGE);

		//If data is invalid, exit
		if (!jsonData) {
			return;
		}

		//Parse from json
		var structureFromLocalstorage = JSON.parse(jsonData);

		//Restore element in current instance
		this.isAuthenticated = structureFromLocalstorage.isAuthenticated || false;
		this.userId = structureFromLocalstorage.userId || null;
		this.userName = structureFromLocalstorage.userName || null;
		this.email = structureFromLocalstorage.email || null;
		this.password = structureFromLocalstorage.password || null;
		this.lastAccessDate = structureFromLocalstorage.lastAccessDate || null;
		this.personName = structureFromLocalstorage.personName || null;
		this.personSurname = structureFromLocalstorage.personSurname || null;
	}

    /**
     * Get authentication header using credentials
     */
	public getAuthenticationHeaderValue(): string {

		//If email and/or password are empty, return string empty
		if (!this.userName || !this.password) {
			return "";
		}

		//Compose credentials string
		var credentials = this.userName + ":" + this.password;
		var complete = "Basic " + btoa(credentials);

		//Encode in base-64
		return complete;
	}

    /**
     * Get headers
     */
	public getHeaders(): Map<string, string> {

		//Compose headers
		var headers = new Map<string, string>();

		//Get authorization header
		var auth = this.getAuthenticationHeaderValue();

		//If specified, append
		if (auth) {
			headers.set("Authorization", auth);
		}

		//Set accept Language
		headers.set("Accept-Language", "it");

		//Returns headers
		return headers;
	}
}
