﻿import { Injectable } from '@angular/core';
import { Http, Headers } from '@angular/http';
import { Subject } from 'rxjs/subject';
import { Observable } from 'rxjs/observable'

import { environment } from '../../environments/environment';
import { HttpService } from './http.service';
import { UserContract } from '../models/user-contract';
import { AuthenticationHolderService } from '../services/authentication-holder.service'

@Injectable()
export class AuthenticationService extends HttpService {

	/**
	* Constructor
	*/
	public constructor(
		http: Http,
		private authenticationHolder: AuthenticationHolderService) {

		//Invoke super class
		super(http)
	}

    /**
     * Execute sign-in on remote platform
     * @param userName User name
     * @param password Password
     */
	public signIn(userName: string, password: string): Observable<UserContract> {

		//Compose request 
		var request = {
			userName: userName,
			password: password
		};

		//Create observable source
		var observableSource = new Subject<UserContract>();

		//Use base method
		this.postObject(environment.apiBaseUrl + "api/Authentication/SignIn", request, () => new UserContract()).subscribe(

			//Success
			(data) => {

				//Create structure to set authentication
				var authData = {
					userId: data.userId,
					userName: data.userName,
					email: data.email,
					lastAccessDate: data.lastAccessDate,
					personName: data.personName,
					personSurname: data.personSurname,

					//Set used successful password
					password: password,
				};

				//Set authentication on holder
				this.authenticationHolder.setAuthentication(authData);

				//Set success on observable and complete
				observableSource.next(data);
				observableSource.complete();
			},

			//Error
			(error) => {

				//Clear authentication
				this.authenticationHolder.clearAuthentication();

				//Set error on observable and complete
				observableSource.error(error);
				observableSource.complete();
			}
		);

		//Returns observable
		return observableSource.asObservable();
	}

    /**
     * Sign-out current authentication
     */
	public signOut() {

		//Create observable source
		var observableSource = new Subject();

		//Clear authentication 
		this.authenticationHolder.clearAuthentication();

		//Set success on observable and complete
		observableSource.next(null);
		observableSource.complete();

		//Returns observable
		return observableSource.asObservable();
	}
}