﻿import { Injectable } from '@angular/core';
import { Http, Headers } from '@angular/http';
import { Subject } from 'rxjs/subject';
import { Observable } from 'rxjs/observable'

import { environment } from '../../environments/environment';
import { HttpService } from './http.service';
import { CategoryContract } from '../models/category-contract';
import { IntegerResponse } from '../models/integer-response';
import { AuthenticationHolderService } from '../services/authentication-holder.service'

@Injectable()
export class DatabankService extends HttpService {

	/**
	* Constructor
	*/
	public constructor(
		http: Http,
		private authenticationHolder: AuthenticationHolderService) {

		//Invoke super class
		super(http)
	}

    /**
	 * Fetch all categories
	 */
	public fetchAllCategories(): Observable<CategoryContract[]> {

		//Use base method
		return this.postArray(environment.apiBaseUrl + "api/Databank/FetchAllCategories",
			null, () => new CategoryContract(), this.authenticationHolder.getHeaders());
	}

	/**
	 * Count number of categories
	 */
	public countAllCategories(): Observable<IntegerResponse> {

		//Use base method
		return this.postObject(environment.apiBaseUrl + "api/Databank/CountAllCategories", null,
			() => new IntegerResponse(), this.authenticationHolder.getHeaders());
	}

    /**
	 * Count number of user
	 */
	public countAllUsers(): Observable<IntegerResponse> {

		//Use base method
		return this.postObject(environment.apiBaseUrl + "api/Databank/CountAllUsers", null,
			() => new IntegerResponse(), this.authenticationHolder.getHeaders());
	}
}
