﻿import { Component, OnInit } from '@angular/core';
import { Router } from '@angular/router';

import { AuthenticationService } from '../../services/authentication.service';
import { AuthenticationHolderService } from '../../services/authentication-holder.service';
import { environment } from '../../../environments/environment';

@Component({
	selector: 'app-header',
	templateUrl: './header.component.html',
	styleUrls: ['./header.component.css']
})
export class HeaderComponent implements OnInit {

	//Bindables
	public isNavbarExpanded: boolean = false;
	public brand: string = null;
	public authentication: AuthenticationHolderService = null;

    /**
     * Constructor
     * @param authenticationHolderService Authentication holder service
     * @param authenticationService Authentication service
     * @param router Router
     */
	constructor(
		private authenticationHolderService: AuthenticationHolderService,
		private authenticationService: AuthenticationService,
		private router: Router) { }

    /**
     * Raised on component init
     */
	public ngOnInit() {

		//Set authentication and brand
		this.authentication = this.authenticationHolderService;
		this.brand = environment.brand;
	}

	/**
	 * Toggle visibility of toolbar
	 */
	public onToggle() {

		//Invert visibility
		this.isNavbarExpanded = !this.isNavbarExpanded;
	}

	/**
	 * Executes logout of current authentication
	 */
	public signOut() {

		//Invoke method
		this.authenticationService.signOut().subscribe(
			() => {

				//Redirect to home
				this.router.navigate(['']);
			}
		);
	}
}